==> kdeplasma-addons-4.1.4.tar.bz2: kdeplasma-addons-4.1.4/applets/fileWatcher/fileWatcher.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Jesper Thomschutz <jesperht@yahoo.com>          *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#ifndef FILEWATCHER_H
#define FILEWATCHER_H

#include <Plasma/Applet>

class QFile;
class QFileSystemWatcher;
class QTextDocument;
class QGraphicsTextItem;


class FileWatcher : public Plasma::Applet
{
  Q_OBJECT

  public:
    FileWatcher(QObject *parent, const QVariantList &args);
    ~FileWatcher();

    void init();

  protected slots:
    void configAccepted();

  private slots:
    void newData();

    void createConfigurationInterface(KConfigDialog *parent);

    void fontChanged(const QFont& font);
    void fontColorChanged(const QColor& color);
    void newPath(const QString& path);
    void maxRowsChanged(int);

  private:
    void loadFile(const QString& path);

    QFile *file;
    QFileSystemWatcher *watcher;
    QGraphicsTextItem *textItem;
    QTextStream *textStream;
    QTextDocument *textDocument;

    QColor m_tmpColor;
    QFont m_tmpFont;
    QString m_tmpPath;
    int m_tmpMaxRows;
};

K_EXPORT_PLASMA_APPLET(fileWatcher, FileWatcher)

#endif

==> kdeplasma-addons-4.2.0.tar.bz2: kdeplasma-addons-4.2.0/applets/fileWatcher/fileWatcher.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Jesper Thomschutz <jesperht@yahoo.com>          *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
 ***************************************************************************/

#ifndef FILEWATCHER_H
#define FILEWATCHER_H

#include <Plasma/Applet>

#include "ui_fileWatcherConfig.h"

class QFile;
class QFileSystemWatcher;
class QTextDocument;
class FileWatcherTextItem;


class FileWatcher : public Plasma::Applet
{
  Q_OBJECT

  public:
    FileWatcher(QObject *parent, const QVariantList &args);
    ~FileWatcher();

    void init();

  protected:
    void constraintsEvent(Plasma::Constraints constraints);

  protected slots:
    void configAccepted();

  private slots:
    void newData();
    void loadFile(const QString& path);

    void createConfigurationInterface(KConfigDialog *parent);

  private:
    void updateRows();

    QFile *file;
    QFileSystemWatcher *watcher;
    FileWatcherTextItem *textItem;
    QTextStream *textStream;
    QTextDocument *textDocument;

    QString m_tmpPath;

    Ui::fileWatcherConfig ui;
};

K_EXPORT_PLASMA_APPLET(fileWatcher, FileWatcher)

#endif
